package com.ruoyi.basicData.service;

import java.util.List;

import com.ruoyi.basicData.domain.TWarehouseWebcam;

/**
 * 仓库摄像头Service接口
 *
 * @author ruoyi
 * @date 2021-12-21
 */
public interface ITWarehouseWebcamService {
    /**
     * 查询仓库摄像头
     *
     * @param fId 仓库摄像头ID
     * @return 仓库摄像头
     */
    public TWarehouseWebcam selectTWarehouseWebcamById(Long fId);

    /**
     * 查询仓库摄像头
     *
     * @param deviceSerial 设备序列号
     * @return 仓库摄像头
     */
    public TWarehouseWebcam selectTWarehouseWebcamByDeviceSerial(String deviceSerial);

    /**
     * 查询仓库摄像头列表
     *
     * @param tWarehouseWebcam 仓库摄像头
     * @return 仓库摄像头集合
     */
    public List<TWarehouseWebcam> selectTWarehouseWebcamList(TWarehouseWebcam tWarehouseWebcam);

    /**
     * APP查询仓库摄像头列表
     *
     * @param tWarehouseWebcam 仓库摄像头
     * @return 仓库摄像头集合
     */
    public List<TWarehouseWebcam> selectAppTWarehouseWebcamList(TWarehouseWebcam tWarehouseWebcam);

    /**
     * 新增仓库摄像头
     *
     * @param tWarehouseWebcam 仓库摄像头
     * @return 结果
     */
    public int insertTWarehouseWebcam(TWarehouseWebcam tWarehouseWebcam);

    /**
     * 修改仓库摄像头
     *
     * @param tWarehouseWebcam 仓库摄像头
     * @return 结果
     */
    public int updateTWarehouseWebcam(TWarehouseWebcam tWarehouseWebcam);

    /**
     * 批量删除仓库摄像头
     *
     * @param fIds 需要删除的仓库摄像头ID
     * @return 结果
     */
    public int deleteTWarehouseWebcamByIds(Long[] fIds);

    /**
     * 删除仓库摄像头信息
     *
     * @param fId 仓库摄像头ID
     * @return 结果
     */
    public int deleteTWarehouseWebcamById(Long fId);
}
